from torch.optim.lr_scheduler import ReduceLROnPlateau as _ReduceLROnPlateau

ReduceLROnPlateau = _ReduceLROnPlateau

__all__ = [
    "ReduceLROnPlateau"
]